<?php
/**
 * A debug output class for PHP's error_log() command
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class DebugErrorLogOutput extends BaseFrameworkSystem implements Debugger, OutputStreamer {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$debugInstance	The prepared debug instance
	 */
	public final static function createDebugErrorLogOutput () {
		// Get a new instance
		$debugInstance = new DebugErrorLogOutput();

		// Return it
		return $debugInstance;
	}

	/**
	 * Outputs the given data without HTML tags
	 *
	 * @param	$output		The HTML'ed output
	 * @return	void
	 */
	public final function outputStream ($output) {
		// Split multiple lines into and array to put them out line-by-line
		$errorLines = explode("\n", $output);
		foreach ($errorLines as $err) {
			$err = trim($err);
			// Log only none-empty lines
			if (!empty($err)) {
				// Log this line
				error_log(html_entity_decode(strip_tags($err)), 0);
			}
		}
	}

	/**
	 * Output the code
	 *
	 * @return	void
	 */
	public final function output ($outStream = false) {
		// Empty output will be silently ignored
		if ($outStream !== false) {
			$this->outputStream($outStream);
		}
	}
}

// [EOF]
?>
